// This file was generated by gir (https://github.com/gtk-rs/gir)
// from gir-files (https://github.com/gtk-rs/gir-files)
// DO NOT EDIT

use crate::{RenderNode, ffi};
use glib::{prelude::*, translate::*};

glib::wrapper! {
    #[doc(alias = "GskSubsurfaceNode")]
    pub struct SubsurfaceNode(Shared<ffi::GskSubsurfaceNode>);

    match fn {
        ref => |ptr| ffi::gsk_render_node_ref(ptr as *mut ffi::GskRenderNode),
        unref => |ptr| ffi::gsk_render_node_unref(ptr as *mut ffi::GskRenderNode),
    }
}

impl StaticType for SubsurfaceNode {
    fn static_type() -> glib::Type {
        unsafe { from_glib(ffi::gsk_subsurface_node_get_type()) }
    }
}

impl SubsurfaceNode {
    //#[doc(alias = "gsk_subsurface_node_new")]
    //pub fn new(child: impl AsRef<RenderNode>, subsurface: /*Unimplemented*/Option<Basic: Pointer>) -> SubsurfaceNode {
    //    unsafe { TODO: call ffi:gsk_subsurface_node_new() }
    //}

    #[doc(alias = "gsk_subsurface_node_get_child")]
    #[doc(alias = "get_child")]
    pub fn child(&self) -> RenderNode {
        unsafe { from_glib_none(ffi::gsk_subsurface_node_get_child(self.to_glib_none().0)) }
    }

    //#[doc(alias = "gsk_subsurface_node_get_subsurface")]
    //#[doc(alias = "get_subsurface")]
    //pub fn subsurface(node: impl AsRef<DebugNode>) -> /*Unimplemented*/Option<Basic: Pointer> {
    //    unsafe { TODO: call ffi:gsk_subsurface_node_get_subsurface() }
    //}
}
