// This file was generated by gir (https://github.com/gtk-rs/gir)
// from gir-files (https://github.com/gtk-rs/gir-files)
// DO NOT EDIT

use crate::{Renderer, ffi};
use glib::{prelude::*, translate::*};

glib::wrapper! {
    #[doc(alias = "GskCairoRenderer")]
    pub struct CairoRenderer(Object<ffi::GskCairoRenderer, ffi::GskCairoRendererClass>) @extends Renderer;

    match fn {
        type_ => || ffi::gsk_cairo_renderer_get_type(),
    }
}

impl CairoRenderer {
    #[doc(alias = "gsk_cairo_renderer_new")]
    pub fn new() -> CairoRenderer {
        assert_initialized_main_thread!();
        unsafe { Renderer::from_glib_full(ffi::gsk_cairo_renderer_new()).unsafe_cast() }
    }
}

impl Default for CairoRenderer {
    fn default() -> Self {
        Self::new()
    }
}
