// This file was generated by gir (https://github.com/gtk-rs/gir)
// from gir-files (https://github.com/gtk-rs/gir-files)
// DO NOT EDIT

use crate::{Isolation, RenderNode, ffi};
use glib::{prelude::*, translate::*};

glib::wrapper! {
    #[doc(alias = "GskIsolationNode")]
    pub struct IsolationNode(Shared<ffi::GskIsolationNode>);

    match fn {
        ref => |ptr| ffi::gsk_render_node_ref(ptr as *mut ffi::GskRenderNode),
        unref => |ptr| ffi::gsk_render_node_unref(ptr as *mut ffi::GskRenderNode),
    }
}

impl StaticType for IsolationNode {
    fn static_type() -> glib::Type {
        unsafe { from_glib(ffi::gsk_isolation_node_get_type()) }
    }
}

impl IsolationNode {
    #[doc(alias = "gsk_isolation_node_new")]
    pub fn new(child: impl AsRef<RenderNode>, isolations: Isolation) -> IsolationNode {
        skip_assert_initialized!();
        unsafe {
            from_glib_full(ffi::gsk_isolation_node_new(
                child.as_ref().to_glib_none().0,
                isolations.into_glib(),
            ))
        }
    }

    #[doc(alias = "gsk_isolation_node_get_child")]
    #[doc(alias = "get_child")]
    pub fn child(&self) -> RenderNode {
        unsafe { from_glib_none(ffi::gsk_isolation_node_get_child(self.to_glib_none().0)) }
    }

    #[doc(alias = "gsk_isolation_node_get_isolations")]
    #[doc(alias = "get_isolations")]
    pub fn isolations(&self) -> Isolation {
        unsafe {
            from_glib(ffi::gsk_isolation_node_get_isolations(
                self.to_glib_none().0,
            ))
        }
    }
}
